@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use Log::Log4perl qw(:easy);
 
-our $VERSION    = "0.06";
+our $VERSION    = "0.07";
 our $DB_VERSION = "1.1";
 
 ###########################################
@@ -103,8 +103,9 @@ sub create {
 sub lock {
 ###########################################
     my($self) = @_;
-    DEBUG "Lock on";
+    DEBUG "Trying to get lock ($$)";
     $self->{db}->lock();
+    DEBUG "Lock on ($$)";
 }
 
 ###########################################
@@ -865,7 +866,7 @@ will print out something like
 
 and allow for further investigation.
 
-=head1 LEGALESE
+=head1 LICENSE
 
 Copyright 2007 by Mike Schilli, all rights reserved.
 This program is free software, you can redistribute it and/or
